@@ -288,9 +288,9 @@ void CUSB::start(struct usb_device *dev)
     }
 
     if (dev->config == 0) {
-	stringstream msg;
-	msg << "USB device has no configuration: " << usb_strerror();
-	throw exce_t(errOpen,msg.str());
+        stringstream msg;
+        msg << "USB device has no configuration: " << usb_strerror();
+        throw exce_t(errOpen,msg.str());
     }
 
     if (usb_set_configuration(udev, dev->config->bConfigurationValue) < 0) {
@@ -440,6 +440,12 @@ void CUSB::syncup(void)
 
 uint16_t CUSB::getDataType(int data_no, char tag, uint16_t protocol)
 {
+
+    if (protocolArraySize == 0)
+    {
+        return 0;
+    }
+
     // Find the right tag D<Data_no> for <tag><protocol>
     for (uint32_t i=0; i < protocolArraySize-1-data_no; i++) {
         if ((char)protocolArray[i].tag == tag) {
