@@ -91,17 +91,6 @@ void CDevice::_acquire()
         throw exce_t(errSync,msg);
     }
 
-    if(devid) {
-        if(serial->getProductId() != devid) {
-            string msg = "No " + devname + " unit detected. Please retry to select other device driver.";
-            throw exce_t(errSync,msg);
-        }
-    }
-    else {
-        string msg = "No " + devname + " unit detected. Please retry to select other device driver.";
-        throw exce_t(errSync,msg);
-    }
-
 }
 
 
