@@ -828,11 +828,11 @@ void CDevice::_uploadTracks(std::list<Garmin::Track_t>& tracks)
         command.id   = Pid_Trk_Data;
         D302_Trk_t * p = (D302_Trk_t *)command.payload;
         command.size = *trkpt >> *p;
-//        cout << "lat      " << trkpt->lat << endl;
-//        cout << "lon      " << trkpt->lon << endl;
-//        cout << "time      " << trkpt->time << endl;
-//        cout << "alt      " << trkpt->alt << endl;
-//        cout << "size      " << command.size << endl;
+        //        cout << "lat      " << trkpt->lat << endl;
+        //        cout << "lon      " << trkpt->lon << endl;
+        //        cout << "time      " << trkpt->time << endl;
+        //        cout << "alt      " << trkpt->alt << endl;
+        //        cout << "size      " << command.size << endl;
 
         usb->write(command);
 
@@ -1021,7 +1021,7 @@ void CDevice::_uploadCustomIcons(list<Garmin::Icon_t>& icons)
 {
     cout << "running uploadCustomIcons for device " << hex << devid << endl;
 
-	if(usb == 0) return;
+    if(usb == 0) return;
 
     if(devid == 0x0231) return IDeviceDefault::_uploadCustomIcons(icons);
 
@@ -1188,35 +1188,38 @@ void CDevice::_screenshot(char *& clrtbl, char *& data, int& width, int& height)
     cout << "device " << devname << " hor " << screenhflip << " vert " << screenvflip << endl;
 
     if(screenhflip) {
-    	// screen shot is horizontally flipped
-    	if(screenvflip) {
-    		// screen shot is also vertically flipped
+        // screen shot is horizontally flipped
+        if(screenvflip) {
+            // screen shot is also vertically flipped
             for(int r = 0; r < screenheight; ++r) {
                 for(int c = 0; c < screenwidth; ++c) {
                     pScreen[r * screenwidth + c] = buffer[(screenheight - r) * screenwidth - c - 1];
                 }
             }
-    	} else {
-    		// vertical organisation of the screen shot is fine
+        }
+        else {
+            // vertical organisation of the screen shot is fine
             for(int r = 0; r < screenheight; ++r) {
                 for(int c = 0; c < screenwidth; ++c) {
                     pScreen[r * screenwidth + c] = buffer[(r + 1) * screenwidth - c - 1];
                 }
             }
-     	}
-    } else {
-    	// horizontal organisation of the screen shot is fine
-    	if(screenvflip) {
-    		// screen shot is vertically flipped
-    		for(int r = 0; r < screenheight; ++r) {
-    			memcpy(pScreen + r * screenwidth,
-    				   buffer + (screenheight - 1 - r) * screenwidth,
-    				   screenwidth);
-    		}
-    	} else {
-    		// vertical organisation of the screen shot is fine
-    		memcpy(pScreen, buffer, screenheight * screenwidth);
-    	}
+        }
+    }
+    else {
+        // horizontal organisation of the screen shot is fine
+        if(screenvflip) {
+            // screen shot is vertically flipped
+            for(int r = 0; r < screenheight; ++r) {
+                memcpy(pScreen + r * screenwidth,
+                    buffer + (screenheight - 1 - r) * screenwidth,
+                    screenwidth);
+            }
+        }
+        else {
+            // vertical organisation of the screen shot is fine
+            memcpy(pScreen, buffer, screenheight * screenwidth);
+        }
     }
 
     clrtbl  = aClrtbl;
