@@ -93,6 +93,8 @@ extern "C" WIN_EXPORT Garmin::IDevice * initGPSMap60CSx(const char * version)
     GPSMap60CSx::device->devname        = "GPSMap60CSX";
     GPSMap60CSx::device->screenwidth    = 160;
     GPSMap60CSx::device->screenheight   = 240;
+    GPSMap60CSx::device->screenhflip    = false;
+    GPSMap60CSx::device->screenvflip    = true;
     return GPSMap60CSx::device;
 }
 
@@ -235,6 +237,7 @@ extern "C" WIN_EXPORT Garmin::IDevice * initEtrexSummitHC(const char * version)
     return GPSMap60CSx::device;
 }
 
+
 extern "C" WIN_EXPORT Garmin::IDevice * initEtrexLegendCx(const char * version)
 {
     if(strncmp(version,INTERFACE_VERSION,5) != 0) {
