@@ -73,7 +73,7 @@ const string& CDevice::getCopyright()
 
 void CDevice::_acquire()
 {
-#if defined(WORDS_BIGENDIAN) || !defined(CAN_UNALIGNED)
+#if defined(HAVE_BIGENDIAN) || !defined(CAN_UNALIGNED)
     throw exce_t(errSync, "This device has not yet been ported to your platform.");
 #endif
     PROGR_CALLBACK ( 0,"acquiring" );
